package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.sign.Base64;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsArticleContent;
import com.ruoyi.system.service.ICmsArticleContentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文章内容管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/articleContent")
public class CmsArticleContentController extends BaseController
{
    @Autowired
    private ICmsArticleContentService cmsArticleContentService;

    /**
     * 查询文章内容管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsArticleContent cmsArticleContent)
    {
        startPage();
        List<CmsArticleContent> list = cmsArticleContentService.selectCmsArticleContentList(cmsArticleContent);
        return getDataTable(list);
    }

    /**
     * 导出文章内容管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:export')")
    @Log(title = "文章内容管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsArticleContent cmsArticleContent)
    {
        List<CmsArticleContent> list = cmsArticleContentService.selectCmsArticleContentList(cmsArticleContent);
        ExcelUtil<CmsArticleContent> util = new ExcelUtil<CmsArticleContent>(CmsArticleContent.class);
        util.exportExcel(response, list, "文章内容管理数据");
    }

    /**
     * 获取文章内容管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(cmsArticleContentService.selectCmsArticleContentById(id));
    }

    /**
     * 新增文章内容管理
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:add')")
    @Log(title = "文章内容管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsArticleContent cmsArticleContent)
    {
        String content = new String(Base64.decode(cmsArticleContent.getContent()));
        cmsArticleContent.setContent(content);
        return toAjax(cmsArticleContentService.insertCmsArticleContent(cmsArticleContent));
    }

    /**
     * 修改文章内容管理
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:edit')")
    @Log(title = "文章内容管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsArticleContent cmsArticleContent)
    {
        return toAjax(cmsArticleContentService.updateCmsArticleContent(cmsArticleContent));
    }

    /**
     * 删除文章内容管理
     */
    @PreAuthorize("@ss.hasPermi('system:articleContent:remove')")
    @Log(title = "文章内容管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(cmsArticleContentService.deleteCmsArticleContentByIds(ids));
    }
}
