package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsAudioGuide;
import com.ruoyi.system.service.ICmsAudioGuideService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 语音导览管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/audioGuide")
public class CmsAudioGuideController extends BaseController
{
    @Autowired
    private ICmsAudioGuideService cmsAudioGuideService;

    /**
     * 查询语音导览管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsAudioGuide cmsAudioGuide)
    {
        startPage();
        List<CmsAudioGuide> list = cmsAudioGuideService.selectCmsAudioGuideList(cmsAudioGuide);
        return getDataTable(list);
    }

    /**
     * 导出语音导览管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:export')")
    @Log(title = "语音导览管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsAudioGuide cmsAudioGuide)
    {
        List<CmsAudioGuide> list = cmsAudioGuideService.selectCmsAudioGuideList(cmsAudioGuide);
        ExcelUtil<CmsAudioGuide> util = new ExcelUtil<CmsAudioGuide>(CmsAudioGuide.class);
        util.exportExcel(response, list, "语音导览管理数据");
    }

    /**
     * 获取语音导览管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cmsAudioGuideService.selectCmsAudioGuideById(id));
    }

    /**
     * 新增语音导览管理
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:add')")
    @Log(title = "语音导览管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsAudioGuide cmsAudioGuide)
    {
        return toAjax(cmsAudioGuideService.insertCmsAudioGuide(cmsAudioGuide));
    }

    /**
     * 修改语音导览管理
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:edit')")
    @Log(title = "语音导览管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsAudioGuide cmsAudioGuide)
    {
        return toAjax(cmsAudioGuideService.updateCmsAudioGuide(cmsAudioGuide));
    }

    /**
     * 删除语音导览管理
     */
    @PreAuthorize("@ss.hasPermi('system:audioGuide:remove')")
    @Log(title = "语音导览管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cmsAudioGuideService.deleteCmsAudioGuideByIds(ids));
    }
}
