package com.ruoyi.web.controller.system;

import java.util.List;
import java.util.stream.Stream;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.CmsTags;
import com.ruoyi.system.service.ICmsTagsService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsCategory;
import com.ruoyi.system.service.ICmsCategoryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文章分类管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/category")
public class CmsCategoryController extends BaseController
{
    @Autowired
    private ICmsCategoryService cmsCategoryService;
    @Autowired
    private ICmsTagsService tagsService;

    /**
     * 查询文章分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsCategory cmsCategory)
    {
//        startPage();
        List<CmsCategory> list = cmsCategoryService.selectCmsCategoryList(cmsCategory);
        for(int i = 0;i<list.size();i++){
            if(StringUtils.isNotEmpty(list.get(i).getCategoryTags())){
                CmsTags tags = tagsService.selectCmsTagsByTagId(Long.valueOf(list.get(i).getCategoryTags()));
                if(tags != null){
                    list.get(i).setTagName(tags.getTagName());
                }
            }
        }
        return getDataTable(list);
    }

    /**
     * 导出文章分类管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:category:export')")
    @Log(title = "文章分类管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsCategory cmsCategory)
    {
        List<CmsCategory> list = cmsCategoryService.selectCmsCategoryList(cmsCategory);
        ExcelUtil<CmsCategory> util = new ExcelUtil<CmsCategory>(CmsCategory.class);
        util.exportExcel(response, list, "文章分类管理数据");
    }

    /**
     * 获取文章分类管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:category:query')")
    @GetMapping(value = "/{categoryId}")
    public AjaxResult getInfo(@PathVariable("categoryId") Long categoryId)
    {
        return success(cmsCategoryService.selectCmsCategoryByCategoryId(categoryId));
    }

    /**
     * 新增文章分类管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:add')")
    @Log(title = "文章分类管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsCategory cmsCategory)
    {
        return toAjax(cmsCategoryService.insertCmsCategory(cmsCategory));
    }

    /**
     * 修改文章分类管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:edit')")
    @Log(title = "文章分类管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsCategory cmsCategory)
    {
        return toAjax(cmsCategoryService.updateCmsCategory(cmsCategory));
    }

    /**
     * 删除文章分类管理
     */
    @PreAuthorize("@ss.hasPermi('system:category:remove')")
    @Log(title = "文章分类管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{categoryIds}")
    public AjaxResult remove(@PathVariable Long[] categoryIds)
    {
        return toAjax(cmsCategoryService.deleteCmsCategoryByCategoryIds(categoryIds));
    }
}
