package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsMaterial;
import com.ruoyi.system.service.ICmsMaterialService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 素材管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/material")
public class CmsMaterialController extends BaseController
{
    @Autowired
    private ICmsMaterialService cmsMaterialService;

    /**
     * 查询素材管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsMaterial cmsMaterial)
    {
        startPage();
        List<CmsMaterial> list = cmsMaterialService.selectCmsMaterialList(cmsMaterial);
        return getDataTable(list);
    }

    /**
     * 导出素材管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:material:export')")
    @Log(title = "素材管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsMaterial cmsMaterial)
    {
        List<CmsMaterial> list = cmsMaterialService.selectCmsMaterialList(cmsMaterial);
        ExcelUtil<CmsMaterial> util = new ExcelUtil<CmsMaterial>(CmsMaterial.class);
        util.exportExcel(response, list, "素材管理数据");
    }

    /**
     * 获取素材管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:material:query')")
    @GetMapping(value = "/{materialId}")
    public AjaxResult getInfo(@PathVariable("materialId") String materialId)
    {
        return success(cmsMaterialService.selectCmsMaterialByMaterialId(materialId));
    }

    /**
     * 新增素材管理
     */
    @PreAuthorize("@ss.hasPermi('system:material:add')")
    @Log(title = "素材管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsMaterial cmsMaterial)
    {
        return toAjax(cmsMaterialService.insertCmsMaterial(cmsMaterial));
    }

    /**
     * 修改素材管理
     */
    @PreAuthorize("@ss.hasPermi('system:material:edit')")
    @Log(title = "素材管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsMaterial cmsMaterial)
    {
        return toAjax(cmsMaterialService.updateCmsMaterial(cmsMaterial));
    }

    /**
     * 删除素材管理
     */
    @PreAuthorize("@ss.hasPermi('system:material:remove')")
    @Log(title = "素材管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{materialIds}")
    public AjaxResult remove(@PathVariable String[] materialIds)
    {
        return toAjax(cmsMaterialService.deleteCmsMaterialByMaterialIds(materialIds));
    }
}
