package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CmsMaterialGroup;
import com.ruoyi.system.service.ICmsMaterialGroupService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 素材分组管理Controller
 *
 * @author libao
 * @date 2024-05-09
 */
@RestController
@RequestMapping("/system/materialGroup")
public class CmsMaterialGroupController extends BaseController
{
    @Autowired
    private ICmsMaterialGroupService cmsMaterialGroupService;

    /**
     * 查询素材分组管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:list')")
    @GetMapping("/list")
    public TableDataInfo list(CmsMaterialGroup cmsMaterialGroup)
    {
        startPage();
        List<CmsMaterialGroup> list = cmsMaterialGroupService.selectCmsMaterialGroupList(cmsMaterialGroup);
        return getDataTable(list);
    }

    /**
     * 导出素材分组管理列表
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:export')")
    @Log(title = "素材分组管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmsMaterialGroup cmsMaterialGroup)
    {
        List<CmsMaterialGroup> list = cmsMaterialGroupService.selectCmsMaterialGroupList(cmsMaterialGroup);
        ExcelUtil<CmsMaterialGroup> util = new ExcelUtil<CmsMaterialGroup>(CmsMaterialGroup.class);
        util.exportExcel(response, list, "素材分组管理数据");
    }

    /**
     * 获取素材分组管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:query')")
    @GetMapping(value = "/{groupId}")
    public AjaxResult getInfo(@PathVariable("groupId") Long groupId)
    {
        return success(cmsMaterialGroupService.selectCmsMaterialGroupByGroupId(groupId));
    }

    /**
     * 新增素材分组管理
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:add')")
    @Log(title = "素材分组管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmsMaterialGroup cmsMaterialGroup)
    {
        return toAjax(cmsMaterialGroupService.insertCmsMaterialGroup(cmsMaterialGroup));
    }

    /**
     * 修改素材分组管理
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:edit')")
    @Log(title = "素材分组管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmsMaterialGroup cmsMaterialGroup)
    {
        return toAjax(cmsMaterialGroupService.updateCmsMaterialGroup(cmsMaterialGroup));
    }

    /**
     * 删除素材分组管理
     */
    @PreAuthorize("@ss.hasPermi('system:materialGroup:remove')")
    @Log(title = "素材分组管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{groupIds}")
    public AjaxResult remove(@PathVariable Long[] groupIds)
    {
        return toAjax(cmsMaterialGroupService.deleteCmsMaterialGroupByGroupIds(groupIds));
    }
}
