package com.ruoyi.web.controller.system;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.CmsArticle;
import com.ruoyi.system.domain.CmsAudioGuide;
import com.ruoyi.system.domain.CmsCategory;
import com.ruoyi.system.domain.CmsMaterial;
import com.ruoyi.system.mapper.CmsArticleMapper;
import com.ruoyi.system.mapper.CmsAudioGuideMapper;
import com.ruoyi.system.mapper.CmsMaterialMapper;
import com.ruoyi.system.service.ICmsArticleService;
import com.ruoyi.system.service.ICmsCategoryService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author 薛千凝
 * @Date 2023/7/26 8:40
 */
@RestController
@RequestMapping("/door")
@Api(value = "主要接口", tags = "主要接口")
@AllArgsConstructor
public class DoorController extends BaseController {

    private ICmsCategoryService categoryService;

    private ICmsArticleService articleService;
    @Resource
    private CmsMaterialMapper materialMapper;
    @Resource
    private CmsArticleMapper articleMapper;
    @Resource
    private CmsAudioGuideMapper audioGuideMapper;

    /**
     * 查询栏目分类树列表
     */
    @ApiOperation("导航栏菜单查询")
    @PostMapping("/Categorylist")
    public List<CmsCategory> list(CmsCategory category) {
        return categoryService.selectCmsCategoryList(category);
    }

    /**
     * 查询文章管理列表
     */
    @ApiOperation("查询文章")
    @PostMapping("/ArticleList")
    public TableDataInfo list(CmsArticle article) {
//        startPage();
        List<CmsArticle> list = articleService.selectCmsArticleList(article);
        return getDataTable(list);
    }

    @ApiOperation("文章详情查询")
    @ApiImplicitParam(name = "id", value = "文章Id", required = true, dataType = "int", paramType = "path", dataTypeClass = String.class)
    @PostMapping("/getArt/{id}")
    public AjaxResult getArt(@PathVariable String id) {
        try {
            CmsArticle article = articleService.selectCmsArticleById(Long.valueOf(id));
            if (article != null) {
                String path = StringUtils.replace(article.getContent(), "\\\"", "\"");
                article.setContent(path);
                return AjaxResult.success(article);
            }
        } catch (Exception e) {
            return AjaxResult.error("请求参数不存在");
        }
        return AjaxResult.error("请求参数不存在");
    }

    /**
     * 查询素材列表
     */
    @ApiOperation("照片查询")
    @PostMapping("/MaterialList")
    public TableDataInfo list() {
        startPage();
        List<CmsMaterial> list = materialMapper.selectCmsMaterialList(new CmsMaterial());
        return getDataTable(list);
    }

    @ApiOperation("语音导览详情查询")
    @ApiImplicitParam(name = "id", value = "文章Id", required = true, dataType = "int", paramType = "path", dataTypeClass = String.class)
    @PostMapping("/getAudioDetail/{id}")
    public AjaxResult getInfo(@PathVariable String id) {
        try {
            CmsAudioGuide audioGuide = audioGuideMapper.selectCmsAudioGuideById(Long.valueOf(id));
            return AjaxResult.success(audioGuide);
        } catch (Exception e) {
            return AjaxResult.error("请求参数不存在");
        }
    }

    /**
     * 获取语音导览数据
     */
    @ApiOperation("获取语音导览数据")
    @PostMapping("/getAudioGuide")
    public TableDataInfo getAudioGuide() {
        startPage();
        List<CmsAudioGuide> list = audioGuideMapper.selectCmsAudioGuideList(new CmsAudioGuide());
        return getDataTable(list);
    }

    /**
     * 模糊查询首页收索框
     */
    @ApiOperation("模糊查询")
    @PostMapping("/FuzzySearch")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "author", value = "原文作者", dataType = "String", dataTypeClass = String.class),
            @ApiImplicitParam(name = "title", value = "文章标题", dataType = "String", dataTypeClass = String.class),
            @ApiImplicitParam(name = "keywords", value = "关键词", dataType = "String", dataTypeClass = String.class),
            @ApiImplicitParam(name = "description", value = "摘要", dataType = "String", dataTypeClass = String.class),
            @ApiImplicitParam(name = "articleModel", value = "文章模型", dataType = "String", dataTypeClass = String.class)
    })
    public List<CmsArticle> searchArticles(@RequestParam(value = "author", required = false) String author,
                                        @RequestParam(value = "title", required = false) String title,
                                        @RequestParam(value = "keywords", required = false) String keywords,
                                        @RequestParam(value = "description", required = false) String description,
                                        @RequestParam(value = "articleModel", required = false) String articleModel) {
        return articleMapper.selectArticlesFuzzySearch(author, title, keywords, description, articleModel);
    }

    /**
     * 文章阅读数量增加
     */
    @ApiOperation("文章阅读数量增加")
    @RequestMapping(value = "/increaseQuantity", method = RequestMethod.POST)
    public AjaxResult increaseQuantity(@RequestParam("id") String id) {
        try {
            // 判断传入的 id 是否为空
            if (StringUtils.isEmpty(id)) {
                return AjaxResult.error("文章ID未传入");
            }
            // 根据 ID 查询实体对象
            CmsArticle article = articleService.selectCmsArticleById(Long.valueOf(id));
            // 如果实体对象存在
            if (article != null) {
                // 增加数量
                int quantity = article.getOnclick();
                article.setOnclick(quantity + 1);
                // 更新实体对象到数据库
                articleService.updateCmsArticle(article);
                return AjaxResult.success("成功增加数量");
            } else {
                return AjaxResult.error("实体对象不存在");
            }
        } catch (Exception e) {
            // 处理异常
            e.printStackTrace();
            return AjaxResult.error("增加数量失败，发生异常");
        }
    }

    /**
     * 语言标签查询
     *
     * @param categoryTags
     * @return
     */
    @ApiOperation("语言标签查询")
    @GetMapping("/categoryTags")
    public List<CmsCategory> queryByTag(String categoryTags) {
        // 1、查询所有分类（包括树形结构）
        List<CmsCategory> categoryList = categoryService.listWithTree();
        // 2、构建分类标签与分类对象的映射关系
        Map<String, List<CmsCategory>> categoryMap = new HashMap<>();
        buildCategoryMap(categoryList, categoryMap);
        // 3、获取特定标签的分类数据
        return categoryMap.getOrDefault(categoryTags, new ArrayList<>());
    }

    // 递归构建分类标签与分类对象的映射关系
    private void buildCategoryMap(List<CmsCategory> categoryList, Map<String, List<CmsCategory>> categoryMap) {
        for (CmsCategory category : categoryList) {
            String categoryTags = category.getCategoryTags();
            categoryMap.computeIfAbsent(categoryTags, k -> new ArrayList<>()).add(category);
            List<CmsCategory> children = category.getNodes();
            if (children != null) {
                buildCategoryMap(children, categoryMap);
            }
        }
    }

    /**
     * 查询留言列表
     */
//    @ApiOperation("查询留言")
//    @PostMapping("/Wordslist")
//    public TableDataInfo list(CmsLeaveWords cmsLeaveWords)
//    {
//        startPage();
//        List<CmsLeaveWords> list = cmsLeaveWordsService.selectCmsLeaveWordsList(cmsLeaveWords);
//        return getDataTable(list);
//    }

    /**
     * 新增保存留言
     */
//    @ApiOperation("新增留言")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "wordsTheme", value = "留言主题", dataType = "String", dataTypeClass = String.class),
//            @ApiImplicitParam(name = "wordsEmil", value = "邮箱", dataType = "String", dataTypeClass = String.class),
//            @ApiImplicitParam(name = "wordsCms", value = "留言内容", dataType = "String", dataTypeClass = String.class)
//    })
//    @Log(title = "留言", businessType = BusinessType.INSERT)
//    @PostMapping("/WordsAdd")
//    public AjaxResult addSave(CmsLeaveWords cmsLeaveWords)
//    {
//        return toAjax(cmsLeaveWordsService.insertCmsLeaveWords(cmsLeaveWords));
//    }

    /**
     * 查询团队预约列表
     */
//    @ApiOperation("查询团队预约列表")
//    @PostMapping("/MakeAnAppointmentList")
//    public TableDataInfo list(CmsMakeAnAppointment cmsMakeAnAppointment)
//    {
//        startPage();
//        List<CmsMakeAnAppointment> list = cmsMakeAnAppointmentService.selectCmsMakeAnAppointmentList(cmsMakeAnAppointment);
//        return getDataTable(list);
//    }

    /**
     * 新增保存团队预约
     */
//    @ApiOperation("新增团队预约")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "makeLinkman", value = "联系人", dataType = "String", dataTypeClass = String.class),
//            @ApiImplicitParam(name = "makePhone", value = "手机号", dataType = "String", dataTypeClass = String.class),
//            @ApiImplicitParam(name = "makeCompany", value = "单位名称", dataType = "String", dataTypeClass = String.class),
//            @ApiImplicitParam(name = "makeDate", value = "预约时间", dataType = "Date", dataTypeClass = Date.class)
//    })
//    @Log(title = "团队预约", businessType = BusinessType.INSERT)
//    @PostMapping("/MakeAnAppointmentAdd")
//    public AjaxResult addSave(CmsMakeAnAppointment cmsMakeAnAppointment)
//    {
//        return toAjax(cmsMakeAnAppointmentService.insertCmsMakeAnAppointment(cmsMakeAnAppointment));
//    }

}
