package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.utils.Guid;
import com.ruoyi.system.domain.CmsAlbumMaterial;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CmsMaterialMapper;
import com.ruoyi.system.domain.CmsMaterial;
import com.ruoyi.system.service.ICmsMaterialService;

/**
 * 素材管理Service业务层处理
 *
 * @author libao
 * @date 2024-05-09
 */
@Service
public class CmsMaterialServiceImpl implements ICmsMaterialService
{
    @Autowired
    private CmsMaterialMapper cmsMaterialMapper;

    /**
     * 查询素材管理
     *
     * @param materialId 素材管理主键
     * @return 素材管理
     */
    @Override
    public CmsMaterial selectCmsMaterialByMaterialId(String materialId)
    {
        return cmsMaterialMapper.selectCmsMaterialByMaterialId(materialId);
    }

    /**
     * 查询素材管理列表
     *
     * @param cmsMaterial 素材管理
     * @return 素材管理
     */
    @Override
    public List<CmsMaterial> selectCmsMaterialList(CmsMaterial cmsMaterial)
    {
        return cmsMaterialMapper.selectCmsMaterialList(cmsMaterial);
    }

    /**
     * 新增素材管理
     *
     * @param cmsMaterial 素材管理
     * @return 结果
     */
    @Override
    public int insertCmsMaterial(CmsMaterial cmsMaterial)
    {
        cmsMaterial.setMaterialId(Guid.get());
        cmsMaterial.setAuditState("1");
        cmsMaterial.setUseState("0");
        cmsMaterial.setMaterialType("1");
        return cmsMaterialMapper.insertCmsMaterial(cmsMaterial);
    }

    /**
     * 修改素材管理
     *
     * @param cmsMaterial 素材管理
     * @return 结果
     */
    @Override
    public int updateCmsMaterial(CmsMaterial cmsMaterial)
    {
        cmsMaterial.setAuditState("1");
        cmsMaterial.setUseState("1");
        return cmsMaterialMapper.updateCmsMaterial(cmsMaterial);
    }

    /**
     * 批量删除素材管理
     *
     * @param materialIds 需要删除的素材管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsMaterialByMaterialIds(String[] materialIds)
    {
        return cmsMaterialMapper.deleteCmsMaterialByMaterialIds(materialIds);
    }

    /**
     * 删除素材管理信息
     *
     * @param materialId 素材管理主键
     * @return 结果
     */
    @Override
    public int deleteCmsMaterialByMaterialId(String materialId)
    {
        return cmsMaterialMapper.deleteCmsMaterialByMaterialId(materialId);
    }

}
